#
# Conditional build:
%bcond_with	rmtcalls	# Remote Calls
%bcond_with	systemd		# systemd

Summary:	Universal addresses to RPC program number mapper
Summary(pl.UTF-8):	Demon odwzorowujący adresy uniwersalne na numery programów RPC
Name:		rpcbind
Version:	1.2.7
Release:	1%{?tld}
License:	BSD
Group:		Daemons
Source0:	https://downloads.sourceforge.net/rpcbind/%{name}-%{version}.tar.bz2
# Source0-md5:	acd444ed322eb458fbd395ec69c4e083
Source1:	%{name}.init
Source2:	%{name}.sysconfig
Patch0:		%{name}-libwrap.patch
Patch1:		%{name}-syslog.patch
Patch2:		%{name}-sunrpc.patch
Patch3:		%{name}-nss.h.patch
Patch4:		%{name}-systemd.patch
Patch6:		%{name}-tcp-addrs.patch
# http://nfsv4.bullopensource.org/doc/tirpc_rpcbind.php
URL:		http://sourceforge.net/projects/rpcbind/
BuildRequires:	autoconf >= 2.50
BuildRequires:	automake
BuildRequires:	libtirpc-devel >= 1:1.0.1
BuildRequires:	libtool
BuildRequires:	libwrap-devel
BuildRequires:	pkgconfig
BuildRequires:	rpmbuild(macros) >= 1.623
%{?with_systemd:BuildRequires:	systemd-devel}
Requires(post,preun):	/sbin/chkconfig
Requires(post,preun,postun):	systemd-units >= 38
Requires:	/sbin/chkconfig
Requires:	rc-scripts >= 0.4.1.6
Requires:	systemd-units >= 0.38
Provides:	portmap = 8.0
Provides:	user(rpc)
Obsoletes:	portmap < 6.1
Obsoletes:	rpcbind-systemd < 0.2.0-5
Conflicts:	clusternfs < 3.0-0.rc2.3
Conflicts:	flixengine < 8.0.8.2-1
Conflicts:	nfs-utils < 1.1.0-0.rc2.1
Conflicts:	quota-rquotad < 1:3.14-4
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
The rpcbind utility is a server that converts RPC program numbers into
universal addresses. It must be running on the host to be able to make
RPC calls on a server on that machine.

%description -l pl.UTF-8
Narzędzie rpcbind to serwer konwertujący numery programów RPC na
adresy uniwersalne. Musi działać na maszynie, aby można było wykonywać
wywołania RPC na serwerze na tej maszynie.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch6 -p1

%build
%{__libtoolize}
%{__aclocal}
%{__autoconf}
%{__automake}
%configure \
	--sbindir=/sbin \
	--bindir=%{_sbindir} \
	--enable-libwrap \
	%{?with_rmtcalls:--enable-rmtcalls} \
	--enable-warmstarts \
	--with-statedir=/var/lib/rpcbind \
	--with-rpcuser=rpc \
%if %{with systemd}
	--with-systemdsystemunitdir=%{systemdunitdir}
%else
	--without-systemdsystemunitdir
%endif
%{__make}

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{/sbin,%{_sbindir},/etc/{sysconfig,rc.d/init.d},/var/lib/rpcbind}

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

install %{SOURCE1} $RPM_BUILD_ROOT/etc/rc.d/init.d/rpcbind
install %{SOURCE2} $RPM_BUILD_ROOT/etc/sysconfig/rpcbind

%clean
rm -rf $RPM_BUILD_ROOT

%pre
%useradd -u 22 -d /usr/share/empty -s /bin/false -c "Portmapper RPC User" -g nobody rpc

%post
/sbin/chkconfig --add rpcbind
%service rpcbind restart
%systemd_post rpcbind.service

%postun
if [ "$1" = "0" ]; then
	%userremove rpc
fi
%systemd_reload

%preun
if [ "$1" = "0" ]; then
	%service -q rpcbind stop
	/sbin/chkconfig --del rpcbind
fi
%systemd_preun rpcbind.service

%triggerpostun -- %{name} < 0.2.0-5
if [ -f /etc/sysconfig/rpcbind ]; then
	. /etc/sysconfig/rpcbind
	[ "$RPCBIND_VERBOSE" = "no" ] || RPCBIND_OPTIONS="-l"
	[ "$RPCBIND_INSECURE" = "yes" ] && RPCBIND_OPTIONS="$RPCBIND_OPTIONS -i"
	for a in $RPCBIND_ADDRESSES ; do
		RPCBIND_OPTIONS="$RPCBIND_OPTIONS -h $a"
	done
	[ -z "$RPCBIND_OPTIONS" ] && exit 0
	%{__cp} -f /etc/sysconfig/rpcbind /etc/sysconfig/rpcbind.rpmsave
	echo >>/etc/sysconfig/rpcbind
	echo "# Added by rpm trigger" >>/etc/sysconfig/rpcbind
	echo "RPCBIND_OPTIONS=\"$RPCBIND_OPTIONS\"" >> /etc/sysconfig/rpcbind
fi
%systemd_trigger rpcbind.service

%files
%exclude_systemd_files
%defattr(644,root,root,755)
%doc AUTHORS COPYING ChangeLog NEWS README
%attr(754,root,root) /etc/rc.d/init.d/rpcbind
%config(noreplace) %verify(not md5 mtime size) /etc/sysconfig/rpcbind
%attr(755,root,root) /sbin/rpcbind
%attr(755,root,root) %{_sbindir}/rpcinfo
%{_mandir}/man8/rpcbind.8*
%{_mandir}/man8/rpcinfo.8*
%dir %attr(700,rpc,root) %{_var}/lib/%{name}
%if %{with systemd}
%{systemdunitdir}/rpcbind.service
%{systemdunitdir}/rpcbind.socket
%endif

%changelog
* Mon Dec 02 2024 TLD Linux <feedback@tld-linux.org>
- For complete changelog see: http://git.tld-linux.org/?p=packages/rpcbind.git;a=log;h=master

* Sat Oct 05 2024 Jakub Bogusz <qboosh@pld-linux.org> e81f2c6
- updated to 1.2.7

* Sun Dec 03 2023 Marcin Krol <hawk@tld-linux.org> 6704735
- allow building on systems without systemd

* Sun Feb 26 2023 Jan Rękorajski <baggins@pld-linux.org> 08d0979
- prevent systemd from taking over rpcbind ports, rel 2

* Sat May 07 2022 Jakub Bogusz <qboosh@pld-linux.org> 7c84442
- updated to 1.2.6

* Mon Aug 27 2018 Jakub Bogusz <qboosh@pld-linux.org> 3c37f6c
- update to 1.2.5 (note: rmtcalls are now disabled in default build)

* Wed Apr 11 2018 Jakub Bogusz <qboosh@pld-linux.org> 743aa28
- use upstream systemd units (with patch); real life check wanted
- use upstream make install

* Wed Apr 11 2018 Jakub Bogusz <qboosh@pld-linux.org> b89fdff
- updated to 0.2.4 release

* Sun Sep 04 2016 Jan Rękorajski <baggins@pld-linux.org> 8a22ccb
- added 0.2.4-rc1 update patch

* Sun Sep 04 2016 Jan Rękorajski <baggins@pld-linux.org> b784358
- updated BRs

* Sun Sep 04 2016 Jan Rękorajski <baggins@pld-linux.org> d8b0171
- updated to 0.2.3

* Sun Sep 04 2016 Jan Rękorajski <baggins@pld-linux.org> 2d96b52
- rebuild with libtirpc 1.0.1
- release 5 (by relup.sh)

* Mon Mar 02 2015 Elan Ruusamäe <glen@delfi.ee> 78f6547
- x32 rebuild
- release 4 (by relup.sh)

* Sat Nov 23 2013 Elan Ruusamäe <glen@delfi.ee> f8ae197
- release 3 (by relup.sh)

* Sat Nov 23 2013 Elan Ruusamäe <glen@delfi.ee> ce8916e
- unify initscript

* Sat Nov 23 2013 Elan Ruusamäe <glen@delfi.ee> 4fbf1bf
- daemon needs full path to binary

* Mon Sep 16 2013 Jan Rękorajski <baggins@pld-linux.org> 6dcb5b5
- fix missing preprocessor var removed with config.h in 0.2.1
- rel 2

* Mon Aug 19 2013 Jakub Bogusz <qboosh@pld-linux.org> 9425805
- License is BSD, package COPYING
- more verbose files, completed BRs

* Mon Aug 19 2013 Jan Rękorajski <baggins@pld-linux.org> 4705a5b
- updated to 0.2.1
- rmoved patches applied upstream

* Tue Apr 17 2012 Jan Rękorajski <baggins@pld-linux.org> 9782f46
- rel 8
- better systemd deps

* Sat Feb 11 2012 Jan Rękorajski <baggins@pld-linux.org> a5609eb
- rel 7
- use __cp macro in trigger, cp may be an alias

